@@ -20,6 +20,8 @@ class FrameworkCsvLoader(FrameworkLocalFileLoader):
         path_to_csv: Union[str, List[str], Path],
         delimiter: str = ",",
         has_header: bool = True,
+        clean_column_names: bool = False,
+        multiline: bool = False,
         name: Optional[str] = None,
         parameters: Optional[Dict[str, Any]] = None,
         progress_logger: Optional[ProgressLogger] = None,
@@ -28,6 +30,7 @@ class FrameworkCsvLoader(FrameworkLocalFileLoader):
         super().__init__(
             view=view,
             filepath=path_to_csv,
+            clean_column_names=clean_column_names,
             name=name,
             parameters=parameters,
             progress_logger=progress_logger,
@@ -40,7 +43,14 @@ class FrameworkCsvLoader(FrameworkLocalFileLoader):
         self.has_header: Param = Param(self, "has_header", "")
         self._setDefault(has_header=True)
 
-        self._set(delimiter=delimiter, has_header=has_header)
+        self.multiline: Param = Param(self, "multiline", "")
+        self._setDefault(multiline=multiline)
+
+        self._set(
+            delimiter=delimiter,
+            has_header=has_header,
+            clean_column_names=clean_column_names,
+        )
 
     # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
     def setDelimiter(self, value: Param) -> "FrameworkCsvLoader":
@@ -60,6 +70,15 @@ class FrameworkCsvLoader(FrameworkLocalFileLoader):
     def getHasHeader(self) -> bool:
         return self.getOrDefault(self.has_header)  # type: ignore
 
+    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
+    def setMultiline(self, value: Param) -> "FrameworkCsvLoader":
+        self._paramMap[self.multiline] = value
+        return self
+
+    # noinspection PyPep8Naming,PyMissingOrEmptyDocstring
+    def getMultiline(self) -> bool:
+        return self.getOrDefault(self.multiline)  # type: ignore
+
     def getReaderFormat(self) -> str:
         return "csv"
 
@@ -67,5 +86,6 @@ class FrameworkCsvLoader(FrameworkLocalFileLoader):
         options: Dict[str, Any] = {
             "header": "true" if self.getHasHeader() else "false",
             "delimiter": self.getDelimiter(),
+            "multiline": self.getMultiline(),
         }
         return options
