@@ -4,11 +4,14 @@ from pyspark.sql.dataframe import DataFrame
 from pyspark.sql.session import SparkSession
 from pyspark.sql.types import StructType
 
-from spark_pipeline_framework.transformers.framework_select_columns_transformer.v1.framework_select_columns_transformer import \
-    FrameworkSelectColumnsTransformer
+from spark_pipeline_framework.transformers.framework_select_columns_transformer.v1.framework_select_columns_transformer import (
+    FrameworkSelectColumnsTransformer,
+)
 from tests.conftest import clean_spark_session
 
-from spark_pipeline_framework.transformers.framework_csv_loader.v1.framework_csv_loader import FrameworkCsvLoader
+from spark_pipeline_framework.transformers.framework_csv_loader.v1.framework_csv_loader import (
+    FrameworkCsvLoader,
+)
 
 
 # noinspection SqlNoDataSourceInspection
@@ -16,7 +19,7 @@ def test_can_keep_columns(spark_session: SparkSession) -> None:
     # Arrange
     clean_spark_session(spark_session)
 
-    data_dir: Path = Path(__file__).parent.joinpath('./')
+    data_dir: Path = Path(__file__).parent.joinpath("./")
     test_file_path: str = f"{data_dir.joinpath('test.csv')}"
 
     schema = StructType([])
@@ -31,7 +34,7 @@ def test_can_keep_columns(spark_session: SparkSession) -> None:
     ).transform(df)
 
     FrameworkSelectColumnsTransformer(
-        view="my_view", keep_columns=['Column2']
+        view="my_view", keep_columns=["Column2"]
     ).transform(df)
 
     # noinspection SqlDialectInspection
